@@ -1,4 +1,3 @@
-import config from 'config';
 import { getPatientSurveyResponseAnswer } from './getPatientSurveyResponseAnswer';
 
 /**
@@ -11,7 +10,7 @@ import { getPatientSurveyResponseAnswer } from './getPatientSurveyResponseAnswer
  * such that they write their answers to patient record fields (@see WAITM-104).
  * However in the meantime these endpoint handlers allow easy and consistent access to the data.
  */
-export async function getPatientAdditionalData(models, patientId, fieldName) {
+export async function getPatientAdditionalData(models, patientId, settings, fieldName) {
   const { PatientAdditionalData } = models;
 
   const patientAdditionalData = await PatientAdditionalData.findOne({
@@ -25,6 +24,6 @@ export async function getPatientAdditionalData(models, patientId, fieldName) {
     return value;
   }
 
-  const questionId = config?.questionCodeIds[fieldName];
+  const questionId = await settings.get(`questionCodeIds.${fieldName}`);
   return getPatientSurveyResponseAnswer(models, patientId, questionId);
 }
