@@ -1,6 +1,6 @@
 import React from 'react';
 import { Document, StyleSheet, View } from '@react-pdf/renderer';
-import { startCase } from 'lodash';
+import { get, startCase } from 'lodash';
 
 import {
   ENCOUNTER_TYPE_LABELS,
@@ -8,6 +8,7 @@ import {
   DRUG_ROUTE_LABELS,
   NOTE_TYPES,
 } from '@tamanu/constants';
+import { formatShort, formatShortest, formatTime, parseDate } from '@tamanu/utils/dateTime';
 
 import { CertificateHeader, Watermark } from './Layout';
 import { LetterheadSection } from './LetterheadSection';
@@ -20,8 +21,7 @@ import { Footer } from './printComponents/Footer';
 import { useLanguageContext, withLanguageContext } from '../pdf/languageContext';
 import { Page } from '../pdf/Page';
 import { Text } from '../pdf/Text';
-import { formatShort, formatTime } from '@tamanu/utils/dateTime';
-import { getDose, getTranslatedFrequency } from '../medication';
+import { getMedicationDoseDisplay, getTranslatedFrequency } from '../medication';
 
 const borderStyle = '1 solid black';
 
@@ -35,35 +35,19 @@ const pageStyles = StyleSheet.create({
 
 const textStyles = StyleSheet.create({
   sectionTitle: {
-    fontFamily: 'Helvetica-Bold',
     marginBottom: 3,
     fontSize: 11,
-    fontWeight: 500,
   },
   tableColumnHeader: {
-    fontFamily: 'Helvetica-Bold',
+    fontWeight: 700,
     fontSize: 10,
   },
   tableCellContent: {
-    fontFamily: 'Helvetica',
     fontSize: 10,
   },
   tableCellFooter: {
-    fontFamily: 'Helvetica',
     fontSize: 8,
   },
-  headerLabel: {
-    fontSize: 8,
-    fontFamily: 'Helvetica-Bold',
-    fontWeight: 400,
-    color: '#888888',
-  },
-  headerValue: {
-    fontSize: 8,
-    fontWeight: 400,
-    fontFamily: 'Helvetica',
-    color: '#888888',
-  },
 });
 
 const tableStyles = StyleSheet.create({
@@ -89,11 +73,12 @@ const tableStyles = StyleSheet.create({
     flexDirection: 'row',
     borderLeft: borderStyle,
     alignItems: 'flex-start',
-    padding: 7,
+    padding: '5px 5px',
+    fontSize: 8,
   },
   p: {
-    fontFamily: 'Helvetica',
-    fontSize: 10,
+    fontWeight: 400,
+    fontSize: 8,
   },
   notesCell: {
     width: '100%',
@@ -110,8 +95,54 @@ const tableStyles = StyleSheet.create({
   },
 });
 
-const Table = (props) => <View style={tableStyles.table} {...props} />;
-const Row = (props) => (
+const getDateTitleArray = date => {
+  const parsedDate = parseDate(date);
+  const shortestDate = formatShortest(parsedDate);
+  const timeWithSeconds = formatTime(parsedDate);
+
+  return [shortestDate, timeWithSeconds.toLowerCase()];
+};
+
+const formatValue = (value, config) => {
+  const { rounding = 0, unit = '' } = config || {};
+  const float = Number.parseFloat(value);
+
+  if (isNaN(float)) {
+    return value || '—'; // em dash
+  }
+
+  const unitSuffix = unit && unit.length <= 2 ? unit : '';
+  if (rounding > 0 || rounding === 0) {
+    return `${float.toFixed(rounding)}${unitSuffix}`;
+  }
+  return `${float}${unitSuffix}`;
+};
+
+const getVitalsColumn = (startIndex, getTranslation, recordedDates) => {
+  const dateArray = [...recordedDates].reverse().slice(startIndex, startIndex + 12);
+  return [
+    {
+      key: 'measure',
+      title: getTranslation('vitals.table.column.measure', 'Measure'),
+      accessor: ({ value }) => value,
+      style: { width: 140, alignItems: 'flex-end' },
+    },
+    ...dateArray
+      .sort((a, b) => b.localeCompare(a))
+      .map(date => ({
+        title: getDateTitleArray(date),
+        key: date,
+        accessor: cells => {
+          const { value, config } = cells[date];
+          return formatValue(value, config);
+        },
+        style: { width: 60, },
+      })),
+  ];
+};
+
+const Table = props => <View style={tableStyles.table} {...props} />;
+const Row = props => (
   <View
     style={[tableStyles.row, props.width && { width: props.width, justifyContent: 'start' }]}
     {...props}
@@ -123,9 +154,9 @@ const P = ({ style = {}, bold, children }) => (
   </Text>
 );
 
-const Cell = ({ children, style = {} }) => (
+const Cell = ({ children, style = {}, bold = false }) => (
   <View style={[tableStyles.baseCell, style]}>
-    <P>{children}</P>
+    <P bold={bold}>{children}</P>
   </View>
 );
 
@@ -146,6 +177,7 @@ const MultipageTableHeading = ({ title, style = textStyles.sectionTitle }) => {
   let firstPageOccurrence = Number.MAX_SAFE_INTEGER;
   return (
     <Text
+      bold
       fixed
       style={style}
       render={({ pageNumber, subPageNumber }) => {
@@ -165,15 +197,16 @@ const DataTableHeading = ({ columns, title, width }) => {
     <View fixed>
       <MultipageTableHeading title={title} />
       <Row wrap={false} width={width}>
-        {columns.map(({ key, title, style }) => {
+        {columns.map(({ key, title, style }, index) => {
           if (Array.isArray(title)) {
+            const rotateStyle =
+              index > 0 ? { transform: 'rotate(-90deg)', paddingBottom: 10, paddingTop: 10 } : {};
             return (
-              <View
-                key={key}
-                style={[tableStyles.baseCell, { flexDirection: 'column', padding: 4 }, style]}
-              >
-                <P style={{ fontFamily: 'Helvetica-Bold' }}>{title[0]}</P>
-                <P>{title[1]}</P>
+              <View key={key} style={[tableStyles.baseCell, style]}>
+                <View style={rotateStyle}>
+                  <P bold>{title[0]}</P>
+                  <P>{title[1]}</P>
+                </View>
               </View>
             );
           }
@@ -197,10 +230,10 @@ const DataTable = ({ data, columns, title, type }) => {
   return (
     <Table>
       <DataTableHeading columns={columns} title={title} width={width} />
-      {data.map((row) => (
+      {data.map(row => (
         <Row key={row.id} wrap={false} width={width}>
-          {columns.map(({ key, accessor, style }) => (
-            <Cell key={key} style={style}>
+          {columns.map(({ key, accessor, style }, index) => (
+            <Cell key={key} style={style} bold={type === 'vitals' && index === 0}>
               {accessor ? accessor(row) : row[key] || ''}
             </Cell>
           ))}
@@ -265,7 +298,7 @@ const NotesSection = ({ notes }) => {
       <View>
         <MultipageTableHeading title={getTranslation('general.notes.label', 'Notes')} />
         <Table>
-          {notes.map((note) => (
+          {notes.map(note => (
             <>
               <View minPresenceAhead={80} />
               <View style={tableStyles.notesRow} key={note.id}>
@@ -320,11 +353,13 @@ const EncounterRecordPrintoutComponent = ({
   notes,
   discharge,
   medications,
-  getLocalisation,
+  localisation,
   vitalsData,
   recordedDates,
-  getVitalsColumn,
+  settings,
 }) => {
+  const getLocalisation = (key) => get(localisation, key);
+  const getSetting = (key) => get(settings, key);
   const { getTranslation, getEnumTranslation } = useLanguageContext();
   const { watermark, logo } = certificateData;
 
@@ -340,7 +375,8 @@ const EncounterRecordPrintoutComponent = ({
       {
         key: 'dateMoved',
         title: getTranslation('pdf.encounterRecord.dateAndTimeMoved', 'Date & time moved'),
-        accessor: ({ date }) => (date ? `${formatShort(date)} ${formatTime(date)}` : '--/--/---- --:----'),
+        accessor: ({ date }) =>
+          date ? `${formatShort(date)} ${formatTime(date)}` : '--/--/---- --:----',
         style: { width: '35%' },
       },
     ],
@@ -360,7 +396,8 @@ const EncounterRecordPrintoutComponent = ({
       {
         key: 'dateMoved',
         title: getTranslation('pdf.encounterRecord.dateAndTimeMoved', 'Date & time moved'),
-        accessor: ({ date }) => (date ? `${formatShort(date)} ${formatTime(date)}` : '--/--/---- --:----'),
+        accessor: ({ date }) =>
+          date ? `${formatShort(date)} ${formatTime(date)}` : '--/--/---- --:----',
         style: { width: '35%' },
       },
     ],
@@ -438,9 +475,9 @@ const EncounterRecordPrintoutComponent = ({
       {
         key: 'areaToBeImaged',
         title: getTranslation('imaging.areas.label', 'Areas to be imaged'),
-        accessor: (imagingRequest) =>
+        accessor: imagingRequest =>
           imagingRequest?.areas?.length
-            ? imagingRequest?.areas.map((area) => area.name).join(', ')
+            ? imagingRequest?.areas.map(area => area.name).join(', ')
             : imagingRequest?.areaNote,
         style: { width: '25%' },
       },
@@ -460,7 +497,7 @@ const EncounterRecordPrintoutComponent = ({
       {
         key: 'completedDate',
         title: getTranslation('pdf.encounterRecord.completedDate', 'Completed date'),
-        accessor: (imagingRequest) =>
+        accessor: imagingRequest =>
           imagingRequest?.results[0]?.completedAt
             ? formatShort(imagingRequest?.results[0]?.completedAt)
             : '--/--/----',
@@ -477,10 +514,10 @@ const EncounterRecordPrintoutComponent = ({
       {
         key: 'dose',
         title: getTranslation('pdf.table.column.dose', 'Dose'),
-        accessor: (medication) => {
+        accessor: medication => {
           return (
             <Text>
-              {getDose(medication, getTranslation, getEnumTranslation)}
+              {getMedicationDoseDisplay(medication, getTranslation, getEnumTranslation)}
               {medication?.isPrn && ` ${getTranslation('medication.table.prn', 'PRN')}`}
             </Text>
           );
@@ -545,7 +582,7 @@ const EncounterRecordPrintoutComponent = ({
           />
         </CertificateHeader>
         <SectionSpacing />
-        <PatientDetailsWithAddress getLocalisation={getLocalisation} patient={patientData} />
+        <PatientDetailsWithAddress getLocalisation={getLocalisation} patient={patientData} getSetting={getSetting} />
         <SectionSpacing />
         <EncounterDetailsExtended encounter={encounter} discharge={discharge} />
         <SectionSpacing />
@@ -606,7 +643,7 @@ const EncounterRecordPrintoutComponent = ({
       </Page>
       {vitalsData.length > 0 && recordedDates.length > 0 ? (
         <>
-          {[0, 12, 24, 36, 48].map((start) => {
+          {[0, 12, 24, 36, 48].map(start => {
             return recordedDates.length > start ? (
               <Page size="A4" orientation="landscape" style={pageStyles.body}>
                 <MultiPageHeader
@@ -624,7 +661,7 @@ const EncounterRecordPrintoutComponent = ({
                 <TableSection
                   title={getTranslation('pdf.encounterRecord.section.vitals', 'Vitals')}
                   data={vitalsData}
-                  columns={getVitalsColumn(start)}
+                  columns={getVitalsColumn(start, getTranslation, recordedDates)}
                   type="vitals"
                 />
                 <Footer />
